<div {% if multifield.css_id or errors %}id="{{ multifield.css_id }}"{% endif %}
    {% if multifield.css_class %}class="{{ multifield.css_class }}"{% endif %}
    {{ multifield.flat_attrs|safe }}>

    {% if form_show_errors %}
        {% for field in multifield.bound_fields %}
            {% if field.errors %}
                <div class="ui error message">
                    {% for error in field.errors %}
                        <p id="error_{{ forloop.counter }}_{{ field.auto_id }}" class="errorField">
                            {{ error }}
                        </p>
                    {% endfor %}
                </div>
            {% endif %}
        {% endfor %}
    {% endif %}

    {% if multifield.label_html %}
        <p {% if multifield.label_class %}class="{{ multifield.label_class }}"{% endif %}>{{ multifield.label_html|safe }}</p>
    {% endif %}

    <div class="multiField">
        {{ fields_output|safe }}
    </div>

    {% for field in multifield.bound_fields %}
        {% if field.help_text %}
            <p id="hint_{{ field.auto_id }}" class="formHint">{{ field.help_text|safe }}</p>
        {% endif %}
    {% endfor %}
</div>
