{% load crispy_forms_field %}

{% if field.is_hidden %}
    {{ field }}
{% else %}
    <div id="div_{{ field.auto_id }}" class="ctrlHolder{% if field|is_checkbox %} ui checkbox{% elif field.field.required %} required{% endif %}">
        {% if field.label %}
            <label for="{{ field.id_for_label }}">
                {{ field.label|safe }}
            </label>
        {% endif %}

        {% crispy_field field %}

        {% if field.help_text %}
            <div id="hint_{{ field.auto_id }}" class="ui pointing label">{{ field.help_text|safe }}</div>
        {% endif %}
    </div>
{% endif %}
