{% if form_tag %}<form class="ui form{% if form.has_changed and not form.is_valid %} error{% endif %}" {{ flat_attrs|safe }} method="{{ form_method }}" {% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>{% endif %}
    {% if form_method|lower == 'post' and not disable_csrf %}
        {% csrf_token %}
    {% endif %}

    {% include "semantic-ui/display_form.html" %}

    {% if inputs %}
        {% for input in inputs %}
            {% include "semantic-ui/layout/baseinput.html" %}
        {% endfor %}
    {% endif %}
{% if form_tag %}</form>{% endif %}
